@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Node 2.144;
+package Config::Model::Node 2.145;
 
 use Mouse;
 with "Config::Model::Role::NodeLoader";
@@ -37,8 +37,8 @@ with "Config::Model::Role::ComputeFunction";
 with "Config::Model::Role::Constants";
 with "Config::Model::Role::Utils";
 
-use feature qw/signatures/;
-no warnings qw/experimental::signatures/;
+use feature qw/signatures postderef/;
+no warnings qw/experimental::signatures experimental::postderef/;
 
 my %legal_properties = (
     status     => {qw/obsolete 1 deprecated 1 standard 1/},
@@ -1093,11 +1093,15 @@ sub tree_searcher ($self, @args){
     return Config::Model::TreeSearcher->new( node => $self, @args );
 }
 
-sub apply_fixes ($self, $filter = '.') {
+sub apply_fixes ($self, $filter='' ) {
     # define leaf call back
+    my $do_apply = sub ($name) {
+        return $filter ? $name =~ /$filter/ : 1;
+    };
+
     my $fix_leaf = sub {
         my ( $scanner, $data_ref, $node, $element_name, $index, $leaf_object ) = @_;
-        $leaf_object->apply_fixes if $element_name =~ /$filter/;
+        $leaf_object->apply_fixes if $do_apply->($element_name);
     };
 
     my $fix_hash = sub {
@@ -1109,7 +1113,7 @@ sub apply_fixes ($self, $filter = '.') {
         # calls to scan_hash before apply_fixes
         map { $scanner->scan_hash( $data_r, $node, $element, $_ ) } @keys;
 
-        $node->fetch_element($element)->apply_fixes if $element =~ /$filter/;
+        $node->fetch_element($element)->apply_fixes if $do_apply->($element);
     };
 
     my $fix_list = sub {
@@ -1118,7 +1122,7 @@ sub apply_fixes ($self, $filter = '.') {
         return unless @keys;
 
         map { $scanner->scan_list( $data_r, $node, $element, $_ ) } @keys;
-        $node->fetch_element($element)->apply_fixes if $element =~ /$filter/;
+        $node->fetch_element($element)->apply_fixes if $do_apply->($element);
     };
 
     my $scan = Config::Model::ObjTreeScanner->new(
@@ -1183,7 +1187,7 @@ Config::Model::Node - Class for configuration tree node
 
 =head1 VERSION
 
-version 2.144
+version 2.145
 
 =head1 SYNOPSIS
 
