@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Role::Grab 2.144;
+package Config::Model::Role::Grab 2.145;
 
 # ABSTRACT: Role to grab data from elsewhere in the tree
 
@@ -15,11 +15,17 @@ use Mouse::Role;
 use strict;
 use warnings;
 use Carp;
+use 5.20.0;
 
 use List::MoreUtils qw/any/;
 use Mouse::Util;
 use Log::Log4perl qw(get_logger :levels);
 
+with "Config::Model::Role::Utils";
+use feature qw/signatures postderef/;
+no warnings qw/experimental::signatures experimental::postderef/;
+
+
 my $logger = get_logger("Grab");
 
 ## Navigation
@@ -31,14 +37,12 @@ my $logger = get_logger("Grab");
 
 # Now return an object and not a value !
 
-sub grab {
-    my $self = shift;
+sub grab ($self, @args) {
+    my %args = _resolve_arg_shortcut(\@args, 'steps');
     my ( $steps, $mode, $autoadd, $type, $grab_non_available, $check ) =
         ( undef, 'strict', 1, undef, 0, 'yes' );
 
-    my %args = @_ > 1 ? @_ : ( steps => $_[0] );
-
-    $steps               = delete $args{steps} // delete $args{step};
+    $steps              = delete $args{steps} // delete $args{step};
     $mode               = delete $args{mode} if defined $args{mode};
     $autoadd            = delete $args{autoadd} if defined $args{autoadd};
     $grab_non_available = delete $args{grab_non_available}
@@ -159,7 +163,7 @@ COMMAND:
         }
 
         {
-            no warnings "uninitialized";
+            no warnings "uninitialized"; ## no critic (TestingAndDebugging::ProhibitNoWarnings)
             $logger->debug("grab: cmd '$cmd' -> name '$name', action '$action', arg '$arg'");
         }
 
@@ -266,9 +270,8 @@ COMMAND:
     return wantarray ? ( $return, @command ) : $return;
 }
 
-sub grab_value {
-    my $self = shift;
-    my %args = scalar @_ == 1 ? ( steps => $_[0] ) : @_;
+sub grab_value ($self, @args) {
+    my %args = _resolve_arg_shortcut(\@args, 'steps');
 
     my $obj = $self->grab(%args);
 
@@ -281,7 +284,7 @@ sub grab_value {
         object  => $self,
         message => "grab_value: cannot get value of non-leaf or check_list "
             . "item with '"
-            . join( "' '", @_ )
+            . join( "' '", @args )
             . "'. item is $obj"
         )
         unless ref $obj
@@ -296,13 +299,8 @@ sub grab_value {
     return $value;
 }
 
-sub grab_annotation {
-    my $self = shift;
-    my @args = scalar @_ == 1 ? ( steps => $_[0] ) : @_;
-
-    my $obj = $self->grab(@args);
-
-    return $obj->annotation;
+sub grab_annotation ($self, @args) {
+    return $self->grab(@args)->annotation;
 }
 
 sub grab_root {
@@ -354,6 +352,7 @@ sub grab_ancestor_with_element_named {
             );
         }
     }
+    return; # should never be reached...
 }
 
 1;
@@ -370,7 +369,7 @@ Config::Model::Role::Grab - Role to grab data from elsewhere in the tree
 
 =head1 VERSION
 
-version 2.144
+version 2.145
 
 =head1 SYNOPSIS
 
